@@ -11,3 +11,10 @@
 	  "************")
 	}
 }
+
+loadModule("fddm_fit", TRUE)
+
+.onLoad = function(libname, pkgname) {
+  if (requireNamespace("emmeans", quietly = TRUE))
+    emmeans::.emm_register("ddm", pkgname)
+}
